{% extends "admin/index.html" %}
{% load i18n %}

{% block bodyclass %}{{ block.super }} app-{{ app_label }}{% endblock %}

{% if not is_popup %}
    {% block breadcrumbs %}
        <div class="breadcrumbs">
            <a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
            &rsaquo;
            {% for app in app_list %}
                {{ app.name }}
            {% endfor %}
        </div>
    {% endblock %}
{% endif %}

{% block sidebar %}{% endblock %}
