{% load dash_tags %}
{% with widget=widget|apply_class_to_widget:'select !select-bordered select-sm w-full' %}
    <select name="{{ widget.name }}" {% include "django/forms/widgets/attrs.html" %}>
        {% for group_name, group_choices, group_index in widget.optgroups %}
            {% if group_name %}
                <optgroup label="{{ group_name }}">
            {% endif %}
        {% for option in group_choices %}
            {% include option.template_name with widget=option %}
        {% endfor %}
        {% if group_name %}
            </optgroup>
        {% endif %}
        {% endfor %}
    </select>
{% endwith %}
