<div class="form-check">
    <label class="form-check-label">
        <input class="form-check-input" type="{{ widget.type }}" name="{{ widget.name }}" {% if widget.value != None %}
               value="{{ widget.value|stringformat:'s' }}" {% endif %} {% include "django/forms/widgets/attrs.html" %} >
        {{ widget.label }}
    </label>
</div>