{% with id=widget.attrs.id %}
<ul {% if id %} id="{{ id }}" {% endif %}{% if widget.attrs.class %} class="{{ widget.attrs.class|cut:'form-control' }}" {% endif %}>
    {% for group, options, index in widget.optgroups %}
    {% if group %}
    <li>{{ group }}
        <ul {% if id %} id="{{ id }}_{{ index }}" {% endif %}>
            {% endif %}
            {% for option in options %}
            <li>
                {% include option.template_name with widget=option %}
            </li>
            {% endfor %}
            {% if group %}
        </ul>
    </li>
    {% endif %}
    {% endfor %}
</ul>
{% endwith %}
