{% extends "admin/base.html" %}
{% load i18n %}

{% block title %}{{ title }}{% endblock %}
{% block content_title %}<h1>{{ title }}</h1>{% endblock %}

{% block content %}
    <div class="bg-white p-3 shadow-1">
        <p class="h4 ">{% translate 'Your password was changed.' %}</p>
    </div>
{% endblock %}
