{% load  dash_tags %}
{% if widget.name == '_selected_action' %}
    {% with widget=widget|apply_class_to_widget:'checkbox-xs checkbox' %}
        <input type="{{ widget.type }}" name="{{ widget.name }}" {% if widget.value != None %}
               value="{{ widget.value|stringformat:'s' }}"{% endif %}{% include "django/forms/widgets/attrs.html" %}  >
    {% endwith %}
{% else %}
    {% with widget=widget|apply_class_to_widget:'toggle-sm border-black/30 toggle' %}
        <input type="{{ widget.type }}" name="{{ widget.name }}" {% if widget.value != None %}
               value="{{ widget.value|stringformat:'s' }}"{% endif %}{% include "django/forms/widgets/attrs.html" %}  >
    {% endwith %}
{% endif %}