
*:focus-visible {
    outline: none !important;
}

[dir="rtl"] .file-input::-webkit-file-upload-button {
    margin-right: 0 !important; /* For WebKit browsers in RTL */
}

[dir="rtl"] .file-input::file-selector-button {
    margin-right: 0 !important; /* For modern browsers in RTL */
}

.errorlist {
    @apply label px-0;
}

.errorlist li {
    @apply label-text text-error font-bold;
}


.card {
    @apply rounded-md shadow-sm;
}

.input, .select, .checkbox, .radio {
    @apply focus:outline-0 transition-all focus:outline-offset-0 border-base-content/20;
    @apply rounded-md;
}

.empty-form {
    @apply hidden;
}

.add-row a {
    @apply btn-link  text-primary;
}

label.required::after {
    content: ' *';
    @apply text-error px-1.5 text-base absolute;
}

.selector input {
    @apply input input-sm border;
}

.selector select {
    @apply select select-sm border min-h-64 w-full;
}

.selector ul.selector-chooser {
    @apply flex flex-col justify-center items-center w-20 bg-base-200;
}

.selector h2 {
    @apply font-bold p-2 text-sm;
}

.selector a {
    @apply text-sm link link-hover;
}

.selector-chosen h2 {
    @apply bg-indigo-400;
}

span.select2-container {
    @apply select-sm border rounded-md select-bordered pl-0;
    @apply h-auto !important;
}

.select2-search--dropdown {
    @apply bg-base-200;
}

span.select2-search input.select2-search__field {
    @apply focus:outline-0 transition-all focus:outline-offset-0 border-base-content/20;
    @apply rounded-md input input-sm border;
}

.select2-container .select2-selection--single {
    @apply p-0 !important;
}

.select2-results {
    @apply menu bg-base-200;
}

span.select2-selection__clear {
    @apply p-1 font-bold text-red-500 text-sm;
}

span.select2-selection__clear:hover {
    @apply text-lg animate-ping;
}

.select2-results .select2-results__options {
    @apply max-h-64 overflow-x-auto;
}

.select2-results__option:hover {
    @apply bg-base-300;
}

.select2-results__option {
    border-bottom: 1px solid rgba(128, 128, 128, 0.09);
}

.select2-selection__rendered {
    @apply flex w-full h-auto flex-wrap !important;

}

.select2-selection__choice {
    @apply inline-block badge-md badge badge-outline m-1 p-1 px-1.5 h-auto;
}

.select2-selection__choice__remove {
    @apply bg-base-300 text-base-content rounded-full inline-block text-center me-1;
    width: 20px;
    height: 20px;
}

li[aria-selected="true"] {
    @apply hidden;
}

a.inline-deletelink:hover {
    @apply text-red-500 animate-pulse text-lg;
}

.select2-dropdown {
    @apply border-none bg-transparent !important;
}

a.tab-active i {
    @apply animate-bounce-once opacity-85 !important;
}

.ts-wrapper .ts-control {
    @apply bg-base-200 border border-base-300 !important;
}

.ts-wrapper .ts-control > div {
    @apply border-base-300 border bg-base-300 text-base-content !important ;
}

.json-field-viewer-wrapper input {
    @apply input-sm;
}

div[data-theme="tailwind"] div[data-schematype]:not([data-schematype="object"]):hover {
    background-color: initial !important;
}

input[data-jdp] {
    @apply input input-sm;
}

/*auth selector admin widget */
.related-widget-wrapper div.selector{
    @apply w-full flex flex-wrap ;
}

.related-widget-wrapper div.selector a{
    @apply btn btn-xs my-1;
}
.related-widget-wrapper div.selector ul.selector-chooser{
    @apply bg-transparent;
}
.related-widget-wrapper div.selector .selector-available{
    @apply flex-1;
}
.related-widget-wrapper div.selector .selector-available input{
    @apply w-full;
}
.related-widget-wrapper div.selector .selector-chosen{
    @apply flex-1;
}