{% load i18n admin_urls %}

<div class="text-start flex gap-2">
    {% url opts|admin_urlname:'history' original.pk|admin_urlquote as history_url %}
    <a href="{% add_preserved_filters history_url %}" class="sm:btn-auto btn-block historylink btn-sm btn btn-info rounded-md">
        {% translate "History" %}
        <i class="fa fa-history"></i>
    </a>
    {% if has_absolute_url %}
        <a href="{{ absolute_url }}"
           class="viewsitelink btn btn-info btn-sm">
            {% translate "View on site" %}
            <i class="fas fa-external-link-alt"></i>
        </a>
    {% endif %}
</div>


