{% load dash_tags %}
{% with widget=widget|apply_class_to_widget:'file-input file-input-bordered file-input-sm w-full max-w-xs focus:outline-0 transition-all focus:outline-offset-0' %}
    {% if widget.is_initial %}
        {{ widget.initial_text }}: <a href="{{ widget.value.url }}">{{ widget.value }}</a>
        {% if not widget.required %}
            <input type="checkbox" name="{{ widget.checkbox_name }}" id="{{ widget.checkbox_id }}" >
            <label for="{{ widget.checkbox_id }}">{{ widget.clear_checkbox_label }}</label>{% endif %}<br>
        {{ widget.input_text }}:{% endif %}
    <input type="{{ widget.type }}" name="{{ widget.name }}"{% include "django/forms/widgets/attrs.html" %}>

{% endwith %}



